FileReader

Trait FileReader 

pub trait FileReader: StreamReader<File> {
    // Provided method
    fn open<P: AsRef<Path>>(
        path: P,
        network_name: impl Into<String>,
    ) -> Result<Self::File, E2sError> { ... }
}
FileReader provides reading era file operations for era files

Provided Methods

fn open<P: AsRef<Path>>( path: P, network_name: impl Into<String>, ) -> Result<Self::File, E2sError>

Opens and reads an era file from the given path

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors