pub struct Proof {
pub data: Vec<u8>,
}Expand description
A proof entry attesting to block validity against a trusted consensus layer header.
Format: snappyFramed(rlp([proof-type, ssz(proof-object)]))
Multiple proof types can coexist in the same file at fork boundaries.
Fields
data: Vec<u8>The compressed data containing rlp([proof-type, ssz(proof-object)])
Implementations
Sourceimpl Proof
impl Proof