pub struct EreId {
pub network_name: String,
pub start_block: BlockNumber,
pub block_count: u32,
pub hash: Option<[u8; 4]>,
pub include_era_count: bool,
pub profiles: Vec<EreProfile>,
}Expand description
ere file identifier
Fields
network_name: StringNetwork configuration name
start_block: BlockNumberFirst block number in file
block_count: u32Number of blocks in the file
hash: Option<[u8; 4]>Optional hash identifier for this file. First 4 bytes of the hash of the last block in the file.
include_era_count: boolWhether to include era count in filename. It is used for custom exports when we don’t use the max number of items per file.
profiles: Vec<EreProfile>Subset profiles applied to this file.
Kept sorted and deduplicated by the builders so the filename postfix renders in the spec-mandated alphabetical order. Empty means the default, fully verifiable profile.
Implementations
Sourceimpl EreId
impl EreId
Sourcepub fn new(
network_name: impl Into<String>,
start_block: BlockNumber,
block_count: u32,
) -> Self
pub fn new( network_name: impl Into<String>, start_block: BlockNumber, block_count: u32, ) -> Self
Create a new EreId
Sourcepub const fn with_era_count(self) -> Self
pub const fn with_era_count(self) -> Self
Include era count in filename, for custom block-per-file exports
Sourcepub fn with_profile(self, profile: EreProfile) -> Self
pub fn with_profile(self, profile: EreProfile) -> Self
Add a subset EreProfile to this file, keeping profiles sorted and deduplicated.
Sourcepub fn with_profiles(
self,
profiles: impl IntoIterator<Item = EreProfile>,
) -> Self
pub fn with_profiles( self, profiles: impl IntoIterator<Item = EreProfile>, ) -> Self
Add several subset profiles to this file, keeping profiles sorted and deduplicated.